package com.ruoyi.traceability.service;

import java.util.List;
import com.ruoyi.traceability.domain.ProLyUpload;

/**
 * 冷压数据上传Service接口
 * 
 * @author wenjy
 * @date 2022-11-22
 */
public interface IProLyUploadService 
{
    /**
     * 查询冷压数据上传
     * 
     * @param id 冷压数据上传主键
     * @return 冷压数据上传
     */
    public ProLyUpload selectProLyUploadById(Long id);

    /**
     * 查询冷压数据上传列表
     * 
     * @param proLyUpload 冷压数据上传
     * @return 冷压数据上传集合
     */
    public List<ProLyUpload> selectProLyUploadList(ProLyUpload proLyUpload);

    /**
     * 新增冷压数据上传
     * 
     * @param proLyUpload 冷压数据上传
     * @return 结果
     */
    public int insertProLyUpload(ProLyUpload proLyUpload);

    /**
     * 修改冷压数据上传
     * 
     * @param proLyUpload 冷压数据上传
     * @return 结果
     */
    public int updateProLyUpload(ProLyUpload proLyUpload);

    /**
     * 批量删除冷压数据上传
     * 
     * @param ids 需要删除的冷压数据上传主键集合
     * @return 结果
     */
    public int deleteProLyUploadByIds(String ids);

    /**
     * 删除冷压数据上传信息
     * 
     * @param id 冷压数据上传主键
     * @return 结果
     */
    public int deleteProLyUploadById(Long id);
}
